@@ -39,8 +39,9 @@ string-value = Value
 ####################################################
 [another-section]
 
-multi_line = This line spans multiple lines and will be written out as such. When
-    it is long enough, it will wrap.
+multi_line = This line spans multiple lines and
+    will be written out as such. It will wrap
+    where it originally wrapped.
 """
 
 
@@ -62,7 +63,7 @@ class TestDotNotationConfig(object):
     assert config.types.string_value == 'Value'
 
     assert config.another_section.multi_line == \
-      'This line spans multiple lines and will be written out as such. When\nit is long enough, it will wrap.'
+      'This line spans multiple lines and\nwill be written out as such. It will wrap\nwhere it originally wrapped.'
 
     with pytest.raises(NoSectionError):
       config.no_section
@@ -85,6 +86,10 @@ class TestDotNotationConfig(object):
     config.read(StringIO(TEST_CONFIG))
     assert 'types' in config
 
+    assert [('multi_line', 'This line spans multiple lines and\nwill be written out as such. '
+                           'It will wrap\nwhere it originally wrapped.')] == list(config.items('another-section'))
+    assert list(config.items('another-section')) == list(config.items('another_section'))
+
   def test_write(self, config):
     temp_file = os.path.join(tempfile.gettempdir(), 'saved-localconfig')
     try:
